@@ -21,6 +21,7 @@ from cliff import lister
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
+from osc_lib.utils import tags as _tag
 from oslo_utils import uuidutils
 
 from octaviaclient.osc.v2 import constants as const
@@ -32,7 +33,7 @@ class ListMember(lister.Lister):
     """List members in a pool"""
 
     def get_parser(self, prog_name):
-        parser = super(ListMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -40,16 +41,17 @@ class ListMember(lister.Lister):
             help="Pool name or ID to list the members of."
         )
 
+        _tag.add_tag_filtering_option_to_parser(parser, 'member')
+
         return parser
 
     def take_action(self, parsed_args):
         columns = const.MEMBER_COLUMNS
 
         attrs = v2_utils.get_member_attrs(self.app.client_manager, parsed_args)
-        pool_id = attrs.pop('pool_id')
 
         data = self.app.client_manager.load_balancer.member_list(
-            pool_id=pool_id)
+            **attrs)
 
         return (columns,
                 (utils.get_dict_properties(
@@ -62,7 +64,7 @@ class ShowMember(command.ShowOne):
     """Shows details of a single Member"""
 
     def get_parser(self, prog_name):
-        parser = super(ShowMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -97,15 +99,17 @@ class ShowMember(command.ShowOne):
             data = self.app.client_manager.load_balancer.member_show(
                 pool_id=pool_id, member_id=member_id)
 
+        formatters = {'tags': v2_utils.format_list_flat}
+
         return (rows, (utils.get_dict_properties(
-            data, rows, formatters={})))
+            data, rows, formatters=formatters)))
 
 
 class CreateMember(command.ShowOne):
     """Creating a member in a pool"""
 
     def get_parser(self, prog_name):
-        parser = super(CreateMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -122,13 +126,13 @@ class CreateMember(command.ShowOne):
             '--disable-backup',
             action='store_true',
             default=None,
-            help="Disable member backup (default)"
+            help="Disable member backup (default)."
         )
         backup.add_argument(
             '--enable-backup',
             action='store_true',
             default=None,
-            help="Enable member backup"
+            help="Enable member backup."
         )
         parser.add_argument(
             '--weight',
@@ -141,7 +145,7 @@ class CreateMember(command.ShowOne):
         parser.add_argument(
             '--address',
             metavar='<ip_address>',
-            help="The IP address of the backend member server",
+            help="The IP address of the backend member server.",
             required=True
         )
         parser.add_argument(
@@ -175,20 +179,23 @@ class CreateMember(command.ShowOne):
             '--enable',
             action='store_true',
             default=None,
-            help="Enable member (default)"
+            help="Enable member (default)."
         )
         admin_group.add_argument(
             '--disable',
             action='store_true',
             default=None,
-            help="Disable member"
+            help="Disable member."
         )
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
+        _tag.add_tag_option_to_parser_for_create(
+            parser, 'member')
+
         return parser
 
     def take_action(self, parsed_args):
@@ -218,16 +225,18 @@ class CreateMember(command.ShowOne):
                         pool_id, data['member']['id']))
             }
 
+        formatters = {'tags': v2_utils.format_list_flat}
+
         return (rows,
                 (utils.get_dict_properties(
-                    data['member'], rows, formatters={})))
+                    data['member'], rows, formatters=formatters)))
 
 
 class SetMember(command.Command):
     """Update a member"""
 
     def get_parser(self, prog_name):
-        parser = super(SetMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -237,38 +246,38 @@ class SetMember(command.Command):
         parser.add_argument(
             'member',
             metavar='<member>',
-            help="Name or ID of the member to update"
+            help="Name or ID of the member to update."
         )
         parser.add_argument(
             '--name',
             metavar='<name>',
-            help="Set the name of the member"
+            help="Set the name of the member."
         )
         backup = parser.add_mutually_exclusive_group()
         backup.add_argument(
             '--disable-backup',
             action='store_true',
             default=None,
-            help="Disable member backup (default)"
+            help="Disable member backup (default)."
         )
         backup.add_argument(
             '--enable-backup',
             action='store_true',
             default=None,
-            help="Enable member backup"
+            help="Enable member backup."
         )
         parser.add_argument(
             '--weight',
             metavar='<weight>',
             type=int,
-            help="Set the weight of member in the pool"
+            help="Set the weight of member in the pool."
         )
         parser.add_argument(
             '--monitor-port',
             metavar='<monitor_port>',
             type=int,
             help="An alternate protocol port used for health monitoring a "
-                 "backend member",
+                 "backend member.",
         )
         parser.add_argument(
             '--monitor-address',
@@ -281,19 +290,21 @@ class SetMember(command.Command):
             '--enable',
             action='store_true',
             default=None,
-            help="Set the admin_state_up to True"
+            help="Set the admin_state_up to True."
         )
         admin_group.add_argument(
             '--disable',
             action='store_true',
             default=None,
-            help="Set the admin_state_up to False")
+            help="Set the admin_state_up to False.")
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
+        _tag.add_tag_option_to_parser_for_set(parser, 'member')
+
         return parser
 
     def take_action(self, parsed_args):
@@ -303,6 +314,14 @@ class SetMember(command.Command):
 
         pool_id = attrs.pop('pool_id')
         member_id = attrs.pop('member_id')
+
+        member_show = functools.partial(
+            self.app.client_manager.load_balancer.member_show,
+            pool_id
+        )
+        v2_utils.set_tags_for_set(
+            member_show, member_id, attrs, clear_tags=parsed_args.no_tag)
+
         post_data = {"member": attrs}
 
         self.app.client_manager.load_balancer.member_set(
@@ -312,10 +331,6 @@ class SetMember(command.Command):
         )
 
         if parsed_args.wait:
-            member_show = functools.partial(
-                self.app.client_manager.load_balancer.member_show,
-                pool_id
-            )
             v2_utils.wait_for_active(
                 status_f=member_show,
                 res_id=member_id
@@ -326,7 +341,7 @@ class DeleteMember(command.Command):
     """Delete a member from a pool """
 
     def get_parser(self, prog_name):
-        parser = super(DeleteMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -342,7 +357,7 @@ class DeleteMember(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         return parser
@@ -372,7 +387,7 @@ class UnsetMember(command.Command):
     """Clear member settings"""
 
     def get_parser(self, prog_name):
-        parser = super(UnsetMember, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'pool',
@@ -412,34 +427,41 @@ class UnsetMember(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
+        _tag.add_tag_option_to_parser_for_unset(parser, 'member')
+
         return parser
 
     def take_action(self, parsed_args):
         unset_args = v2_utils.get_unsets(parsed_args)
-        if not unset_args:
+        if not unset_args and not parsed_args.all_tag:
             return
 
         pool_id = v2_utils.get_resource_id(
             self.app.client_manager.load_balancer.pool_list,
             'pools', parsed_args.pool)
 
+        member_show = functools.partial(
+            self.app.client_manager.load_balancer.member_show,
+            pool_id
+        )
+
         member_dict = {'pool_id': pool_id, 'member_id': parsed_args.member}
         member_id = v2_utils.get_resource_id(
             self.app.client_manager.load_balancer.member_list,
             'members', member_dict)
 
+        v2_utils.set_tags_for_unset(
+            member_show, member_id, unset_args,
+            clear_tags=parsed_args.all_tag)
+
         body = {'member': unset_args}
 
         self.app.client_manager.load_balancer.member_set(
             pool_id=pool_id, member_id=member_id, json=body)
 
         if parsed_args.wait:
-            member_show = functools.partial(
-                self.app.client_manager.load_balancer.member_show,
-                pool_id
-            )
             v2_utils.wait_for_active(
                 status_f=member_show,
                 res_id=member_id
